@@ -26,9 +26,10 @@ detachFromSearchPath <- function(p){
     for(to.detach in d){
       try({
         suppressWarnings(
-        detach(name = makeDetachString(to.detach), unload = TRUE, force = TRUE, character.only = TRUE)
-      )},
-      silent = TRUE
+          detach(name = makeDetachString(to.detach), unload = TRUE, 
+                 force = TRUE, character.only = TRUE)
+        )},
+        silent = TRUE
       )
     }
     n <- n + 1
