@@ -1,26 +1,29 @@
 # tests for checking file system authorization
 if(interactive()) library(testthat)
+library(mockery)
 
 context("file system authorization")
 td <- file.path(tempdir(), "checkpoint_not_auth")
 unlink(td, recursive = TRUE)
 
 test_that("stops without authorization in interactive mode", {
-  with_mock(
-    `base::readline` = function(prompt)"n",
-    expect_error(
-      authorizeFileSystemUse(td, interactive=TRUE),
-      "Cannot proceed without access to checkpoint directory"
-    )
+  stub(authorizeFileSystemUse, 
+       "readline", 
+       function(prompt)"n"
+  )
+  expect_error(
+    authorizeFileSystemUse(td, interactive=TRUE),
+    "Cannot proceed without access to checkpoint directory"
   )
 })
 
 test_that("continues with authorization in interactive mode", {
-  with_mock(
-    `base::readline` = function(prompt)"y",
-    expect_null(
-      authorizeFileSystemUse(td, interactive=TRUE)    
-    )
+  stub(authorizeFileSystemUse,
+       "readline", 
+       function(prompt)"y"
+  )
+  expect_null(
+    authorizeFileSystemUse(td, interactive=TRUE)    
   )
 })
 
